@@ -335,7 +335,7 @@ class ModelStorage(Model):
             data = convert_data(field_defs, datas[id])
             to_create.append(data)
         new_records = cls.create(to_create)
-        new_ids = dict(izip(ids, map(int, new_records)))
+        id2new_record = dict(izip(ids, new_records))
 
         fields_translate = {}
         for field_name, field in field_defs.iteritems():
@@ -355,11 +355,13 @@ class ModelStorage(Model):
                             fuzzy_translation=False):
                         datas = cls.read(ids,
                                 fields_names=fields_translate.keys() + ['id'])
+                        to_write = []
                         for data in datas:
-                            data_id = data['id']
-                            data = convert_data(fields_translate, data)
-                            cls.write([cls(new_ids[data_id])], data)
-        return cls.browse(new_ids.values())
+                            to_write.append([id2new_record[data['id']]])
+                            to_write.append(
+                                convert_data(fields_translate, data))
+                        cls.write(*to_write)
+        return new_records
 
     @classmethod
     def search(cls, domain, offset=0, limit=None, order=None, count=False):
@@ -974,10 +976,12 @@ class ModelStorage(Model):
             if relations:
                 for sub_relations in grouped_slice(relations):
                     sub_relations = set(sub_relations)
-                    finds = Relation.search(['AND',
-                            [('id', 'in', [r.id for r in sub_relations])],
-                            domain,
-                            ])
+                    # Use root user to skip access rules
+                    with Transaction().set_user(0):
+                        finds = Relation.search(['AND',
+                                [('id', 'in', [r.id for r in sub_relations])],
+                                domain,
+                                ])
                     if sub_relations != set(finds):
                         cls.raise_user_error('domain_validation_record',
                             error_args=cls._get_error_args(field.name))
