@@ -154,7 +154,8 @@ class JSONProtocol:
                 response['result'] = data
         else:
             if isinstance(data, Exception):
-                return InternalServerError()
+                return InternalServerError(data)
             response = data
-        return Response(json.dumps(response, cls=JSONEncoder),
+        return Response(json.dumps(
+                response, cls=JSONEncoder, separators=(',', ':')),
             content_type='application/json')
